@@ -1,5 +1,7 @@
 """Flask-Limiter extension for rate limiting."""
 
+from __future__ import annotations
+
 from . import _version
 from .constants import ExemptionScope, HeaderNames
 from .errors import RateLimitExceeded
@@ -17,4 +19,4 @@ __all__ = [
 #: Aliased for backward compatibility
 HEADERS = HeaderNames
 
-__version__ = _version.get_versions()["version"]  # type: ignore
+__version__ = _version.get_versions()["version"]
